//@line 36 "/builds/tinderbox/Fx-Mozilla1.9-l10n-Release/Linux_2.6.18-53.1.13.el5_Depend/l10n/hu/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.9-l10n-Release/Linux_2.6.18-53.1.13.el5_Depend/l10n/hu/browser/firefox-l10n.js"

pref("general.useragent.locale", "hu");
